@@ -23,10 +23,10 @@ from oslo_db.sqlalchemy import enginefacade
 from oslo_db.sqlalchemy import utils as sqlalchemyutils
 from oslo_log import log as logging
 from oslo_utils import timeutils
-from sqlalchemy import or_, and_
-from sqlalchemy.ext.compiler import compiles
+import sqlalchemy as sa
+from sqlalchemy.ext import compiler
 from sqlalchemy import MetaData
-from sqlalchemy.orm import joinedload
+from sqlalchemy import orm
 from sqlalchemy import sql
 import sqlalchemy.sql as sa_sql
 from sqlalchemy.sql import func
@@ -363,8 +363,11 @@ def host_get_all_by_filters(
                                                 sort_dirs)
 
     filters = filters or {}
-    query = model_query(context,
-                        models.Host).options(joinedload('failover_segment'))
+    query = model_query(
+        context, models.Host,
+    ).options(
+        orm.joinedload(models.Host.failover_segment),
+    )
 
     if 'failover_segment_id' in filters:
         query = query.filter(models.Host.failover_segment_id == filters[
@@ -406,9 +409,13 @@ def host_get_by_uuid(context, host_uuid, segment_uuid=None):
 
 
 def _host_get_by_uuid(context, host_uuid, segment_uuid=None):
-    query = model_query(context, models.Host
-                        ).filter_by(uuid=host_uuid
-                                    ).options(joinedload('failover_segment'))
+    query = model_query(
+        context, models.Host,
+    ).filter_by(
+        uuid=host_uuid,
+    ).options(
+        orm.joinedload(models.Host.failover_segment),
+    )
     if segment_uuid:
         query = query.filter_by(failover_segment_id=segment_uuid)
 
@@ -427,9 +434,13 @@ def _host_get_by_uuid(context, host_uuid, segment_uuid=None):
 @oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
 @main_context_manager.reader
 def host_get_by_id(context, host_id):
-    query = model_query(context, models.Host
-                        ).filter_by(id=host_id
-                                    ).options(joinedload('failover_segment'))
+    query = model_query(
+        context, models.Host,
+    ).filter_by(
+        id=host_id,
+    ).options(
+        orm.joinedload(models.Host.failover_segment),
+    )
 
     result = query.first()
     if not result:
@@ -441,9 +452,13 @@ def host_get_by_id(context, host_id):
 @oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
 @main_context_manager.reader
 def host_get_by_name(context, name):
-    query = model_query(context, models.Host
-                        ).filter_by(name=name
-                                    ).options(joinedload('failover_segment'))
+    query = model_query(
+        context, models.Host,
+    ).filter_by(
+        name=name,
+    ).options(
+        orm.joinedload(models.Host.failover_segment),
+    )
 
     result = query.first()
     if not result:
@@ -617,8 +632,117 @@ def notification_delete(context, notification_uuid):
     if count == 0:
         raise exception.NotificationNotFound(id=notification_uuid)
 
+    model_query(context, models.VMove).filter_by(
+        notification_uuid=notification_uuid).soft_delete(
+        synchronize_session=False)
+
+
+# db apis for vm moves
+
+
+@oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
+@main_context_manager.reader
+def vmoves_get_all_by_filters(
+        context, filters=None, sort_keys=None,
+        sort_dirs=None, limit=None, marker=None):
+
+    if limit == 0:
+        return []
+
+    sort_keys, sort_dirs = _process_sort_params(sort_keys,
+                                                sort_dirs)
+
+    filters = filters or {}
+    query = model_query(context, models.VMove)
+
+    if 'notification_uuid' in filters:
+        query = query.filter(models.VMove.notification_uuid == filters[
+            'notification_uuid'])
+
+    if 'type' in filters:
+        query = query.filter(models.VMove.type == filters[
+            'type'])
+
+    if 'status' in filters:
+        status = filters['status']
+        if isinstance(status, (list, tuple, set, frozenset)):
+            column_attr = getattr(models.VMove, 'status')
+            query = query.filter(column_attr.in_(status))
+        else:
+            query = query.filter(models.VMove.status == status)
+
+    marker_row = None
+    if marker is not None:
+        marker_row = model_query(context,
+                                 models.VMove
+                                 ).filter_by(id=marker).first()
+        if not marker_row:
+            raise exception.MarkerNotFound(marker=marker)
+
+    try:
+        query = sqlalchemyutils.paginate_query(query, models.VMove,
+                                               limit,
+                                               sort_keys,
+                                               marker=marker_row,
+                                               sort_dirs=sort_dirs)
+    except db_exc.InvalidSortKey as err:
+        raise exception.InvalidSortKey(err)
+
+    return query.all()
+
+
+@oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
+@main_context_manager.reader
+def vmove_get_by_uuid(context, uuid):
+    return _vmove_get_by_uuid(context, uuid)
+
+
+def _vmove_get_by_uuid(context, uuid):
+    query = model_query(context, models.VMove).filter_by(uuid=uuid)
+
+    result = query.first()
+    if not result:
+        raise exception.VMoveNotFound(id=uuid)
+
+    return result
+
+
+@oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
+@main_context_manager.writer
+def vmove_create(context, values):
+    vm_move = models.VMove()
+    vm_move.update(values)
+
+    vm_move.save(session=context.session)
+
+    return _vmove_get_by_uuid(context, vm_move.uuid)
+
+
+@oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
+@main_context_manager.writer
+def vmove_update(context, uuid, values):
+    vm_move = _vmove_get_by_uuid(context, uuid)
+    vm_move.update(values)
+
+    vm_move.save(session=context.session)
+
+    return _vmove_get_by_uuid(context, vm_move.uuid)
+
+
+@oslo_db_api.wrap_db_retry(max_retries=5, retry_on_deadlock=True)
+@main_context_manager.writer
+def vmove_delete(context, vmove_uuid):
+    count = model_query(context, models.VMove
+                        ).filter_by(uuid=vmove_uuid
+                                    ).soft_delete(synchronize_session=False)
+
+    if count == 0:
+        raise exception.VMoveNotFound(id=vmove_uuid)
+
 
 class DeleteFromSelect(sa_sql.expression.UpdateBase):
+    inherit_cache = False
+
     def __init__(self, table, select, column):
         self.table = table
         self.select = select
@@ -627,7 +751,7 @@ class DeleteFromSelect(sa_sql.expression.UpdateBase):
 
 # NOTE(pooja_jadhav): MySQL doesn't yet support subquery with
 # 'LIMIT & IN/ALL/ANY/SOME' We need work around this with nesting select.
-@compiles(DeleteFromSelect)
+@compiler.compiles(DeleteFromSelect)
 def visit_delete_from_select(element, compiler, **kw):
     return "DELETE FROM %s WHERE %s in (SELECT T1.%s FROM (%s) as T1)" % (
         compiler.process(element.table, asfrom=True),
@@ -647,7 +771,6 @@ def purge_deleted_rows(context, age_in_days, max_rows):
     based on last updated_at and status column.
     """
     engine = get_engine()
-    conn = engine.connect()
     metadata = MetaData()
     metadata.reflect(engine)
     deleted_age = timeutils.utcnow() - datetime.timedelta(days=age_in_days)
@@ -664,21 +787,32 @@ def purge_deleted_rows(context, age_in_days, max_rows):
 
         if table.name == 'notifications':
             status_column = table.c.status
-            query_delete = sql.select([column]).where(
-                and_(updated_at_column < deleted_age, or_(
-                    status_column == 'finished', status_column == 'failed',
-                    status_column == 'ignored'))).order_by(status_column)
+            query_delete = sql.select(column).where(
+                sa.and_(
+                    updated_at_column < deleted_age,
+                    sa.or_(
+                        status_column == 'finished',
+                        status_column == 'failed',
+                        status_column == 'ignored',
+                    ),
+                ),
+            ).order_by(status_column)
         else:
             query_delete = sql.select(
-                [column], deleted_at_column < deleted_age).order_by(
-                deleted_at_column)
+                column,
+            ).where(
+                deleted_at_column < deleted_age,
+            ).order_by(
+                deleted_at_column,
+            )
 
         if max_rows > 0:
             query_delete = query_delete.limit(max_rows - total_rows_purged)
 
         delete_statement = DeleteFromSelect(table, query_delete, column)
 
-        result = conn.execute(delete_statement)
+        with engine.connect() as conn, conn.begin():
+            result = conn.execute(delete_statement)
 
         rows = result.rowcount
         LOG.info('Deleted %(rows)d row(s) from table %(tbl)s',
