@@ -27,6 +27,7 @@ from oslo_utils import importutils
 
 import masakari.conf
 from masakari import context
+from masakari import coordination as masakari_coordination
 from masakari import exception
 from masakari.i18n import _
 from masakari.objects import base as objects_base
@@ -41,17 +42,6 @@ LOG = logging.getLogger(__name__)
 CONF = masakari.conf.CONF
 
 
-def assert_eventlet_uses_monotonic_clock():
-    import eventlet.hubs as hubs
-    import monotonic
-
-    hub = hubs.get_hub()
-    if hub.clock is not monotonic.monotonic:
-        raise RuntimeError(
-            'eventlet hub is not using a monotonic clock - '
-            'periodic tasks will be affected by drifts of system time.')
-
-
 class Service(service.Service):
     """Service object for binaries running on hosts.
 
@@ -89,7 +79,6 @@ class Service(service.Service):
                }
 
     def start(self):
-        assert_eventlet_uses_monotonic_clock()
         verstr = version.version_string_with_package()
         LOG.info('Starting %(topic)s (version %(version)s)', {
             'topic': self.topic,
@@ -200,7 +189,8 @@ class Service(service.Service):
 class WSGIService(service.Service):
     """Provides ability to launch API from a 'paste' configuration."""
 
-    def __init__(self, name, loader=None, use_ssl=False, max_url_len=None):
+    def __init__(self, name, loader=None, use_ssl=False, max_url_len=None,
+                 coordination=False):
         """Initialize, but do not start the WSGI server.
 
         :param name: The name of the WSGI server given to the loader.
@@ -233,6 +223,7 @@ class WSGIService(service.Service):
                                   port=self.port,
                                   use_ssl=self.use_ssl,
                                   max_url_len=max_url_len)
+        self.coordination = coordination
 
     def reset(self):
         """Reset server greenpool size to default.
@@ -251,6 +242,8 @@ class WSGIService(service.Service):
         :returns: None
 
         """
+        if self.coordination:
+            masakari_coordination.COORDINATOR.start()
         self.server.start()
 
     def stop(self):
@@ -259,6 +252,12 @@ class WSGIService(service.Service):
         :returns: None
 
         """
+        if self.coordination:
+            try:
+                masakari_coordination.COORDINATOR.stop()
+            except Exception as error:
+                LOG.warning('Error occurred during masakari coordination was '
+                            'stopped: %s', error)
         self.server.stop()
 
     def wait(self):
