@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from oslo_utils import timeutils
 from taskflow.persistence import models
 from taskflow.persistence import path_based
@@ -339,6 +340,101 @@ class TaskflowDriverTestCase(test.TestCase):
         mock_get_flows_for_book.assert_called_once()
         mock_get_atoms_for_flow.assert_called_once()
 
-        self.assertItemsEqual(expected_result[0], progress_details[0])
-        self.assertItemsEqual(expected_result[1], progress_details[1])
-        self.assertItemsEqual(expected_result[2], progress_details[2])
+        self.assertObjectList(expected_result, progress_details)
+
+    @mock.patch.object(path_based.PathBasedConnection, 'get_atoms_for_flow')
+    @mock.patch.object(path_based.PathBasedConnection, 'get_flows_for_book')
+    def test_get_notification_recovery_workflow_details_raises_keyerror(
+            self, mock_get_flows_for_book, mock_get_atoms_for_flow):
+
+        notification = fakes.create_fake_notification(
+            payload={
+                'event': 'LIFECYCLE', 'instance_uuid': uuidsentinel.fake_ins,
+                'vir_domain_event': 'STOPPED_FAILED'},
+            source_host_uuid=uuidsentinel.fake_host,
+            notification_uuid=uuidsentinel.fake_notification)
+
+        fd = models.FlowDetail('test', uuid=notification.notification_uuid)
+        atom1 = models.TaskDetail('StopInstanceTask',
+                                  uuid=uuidsentinel.atom_id_1)
+        atom1.meta = {
+            'progress': 1.0,
+            'progress_details': {
+                'at_progress': 1.0,
+                'details': {
+                    'progress_details': [
+                        {'timestamp': '2019-03-11 05:22:20.329171',
+                         'message': 'Stopping instance: '
+                                    '87c8ebc3-2a70-49f0-9280-d34662dc203d',
+                         'progress': 0.0},
+                        {'timestamp': '2019-03-11 05:22:28.902665',
+                         'message': "Stopped instance: "
+                                    "'87c8ebc3-2a70-49f0-9280-d34662dc203d'",
+                         'progress': 1.0}]}}}
+        atom1.state = 'SUCCESS'
+
+        atom2 = models.TaskDetail('ConfirmInstanceActiveTask',
+                                  uuid=uuidsentinel.atom_id_2)
+        atom2.meta = {
+            'progress': 1.0,
+            'progress_details': {
+                'at_progress': 1.0,
+                'details': {
+                    'progress_details': [
+                        {'timestamp': '2019-03-11 05:22:29.597303',
+                         'message': "Confirming instance "
+                                    "'87c8ebc3-2a70-49f0-9280-d34662dc203d' "
+                                    "vm_state is ACTIVE",
+                         'progress': 0.0},
+                        {'timestamp': '2019-03-11 05:22:31.916620',
+                         'message': "Confirmed instance "
+                                    "'87c8ebc3-2a70-49f0-9280-d34662dc203d'"
+                                    " vm_state is ACTIVE", 'progress': 1.0}]
+                }}}
+        atom2.state = 'SUCCESS'
+
+        atom3 = models.TaskDetail('StartInstanceTask',
+                                  uuid=uuidsentinel.atom_id_3)
+        atom3.state = 'RUNNING'
+
+        def fd_generator():
+            yield fd
+
+        def atom_detail_generator():
+            for atom in [atom1, atom2, atom3]:
+                yield atom
+
+        flow_details = fd_generator()
+        atom_details = atom_detail_generator()
+        mock_get_flows_for_book.return_value = flow_details
+        mock_get_atoms_for_flow.return_value = atom_details
+        driver.PERSISTENCE_BACKEND = 'memory://'
+
+        progress_details = (
+            self.taskflow_driver.get_notification_recovery_workflow_details(
+                self.ctxt, 'auto', notification))
+
+        # list of NotificationProgressDetails object
+        expected_result = []
+        expected_result.append((
+            fakes.create_fake_notification_progress_details(
+                name=atom1.name,
+                uuid=atom1.uuid,
+                progress=atom1.meta['progress'],
+                state=atom1.state,
+                progress_details=atom1.meta['progress_details']
+                ['details']['progress_details'])))
+        expected_result.append((
+            fakes.create_fake_notification_progress_details(
+                name=atom2.name,
+                uuid=atom2.uuid,
+                progress=atom2.meta['progress'],
+                state=atom2.state,
+                progress_details=atom2.meta['progress_details']
+                ['details']['progress_details'])))
+
+        self.assertIsNotNone(progress_details)
+        mock_get_flows_for_book.assert_called_once()
+        mock_get_atoms_for_flow.assert_called_once()
+
+        self.assertObjectList(expected_result, progress_details)
